@@ -751,7 +751,7 @@ def logonHoursMap(logontimes):
     # See <http://ma.ph-freiburg.de/tng/tng-technical/2003-04/msg00015.html> for details.
 
     newtimes = ""
-    for i in range(0, 21):
+    for i in range(21):
         bitlist = list(logontimes[(i * 8):(i * 8) + 8])
         bitlist.reverse()
         newtimes += "".join(bitlist)
@@ -759,7 +759,7 @@ def logonHoursMap(logontimes):
 
     # create a hexnumber from each 8-bit-segment
     ret = ""
-    for i in range(0, 21):
+    for i in range(21):
         val = 0
         exp = 7
         for j in range((i * 8), (i * 8) + 8):
@@ -779,7 +779,7 @@ def logonHoursUnmap(logontimes):
     """Converts hex-string to an array of bits set."""
     times = logontimes[0][:42]
     while len(times) < 42:
-        times = times
+        times = times  # noqa: PLW0127
     ret = ""
     for i in range(0, 42, 2):
         val = int(times[i:i + 2], 16)
@@ -787,7 +787,7 @@ def logonHoursUnmap(logontimes):
 
     # reverse order of the bits in each byte. See above for details
     newtime = ""
-    for i in range(0, 21):
+    for i in range(21):
         bitlist = list(ret[(i * 8):(i * 8) + 8])
         bitlist.reverse()
         newtime += "".join(bitlist)
@@ -1255,7 +1255,7 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
         if 'automountInformation' not in self.oldattr:
             return
         try:
-            flags, unc = re.split(b' +', self.oldattr['automountInformation'][0], 1)
+            flags, unc = re.split(b' +', self.oldattr['automountInformation'][0], 1)  # noqa: B034
             host, path = unc.split(b':', 1)
         except ValueError:
             return
@@ -1873,7 +1873,7 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
             return ml
 
         try:
-            new = [x[2] if isinstance(x[2], (list, tuple)) else [x[2]] for x in ml if x[0] == 'mailForwardAddress' and x[2]][0]
+            new = [x[2] if isinstance(x[2], (list, tuple)) else [x[2]] for x in ml if x[0] == 'mailForwardAddress' and x[2]][0]  # noqa: RUF015
         except IndexError:  # mailForwardAddress was not changed, nevertheless we might need to change it
             new = self.mapping.mapValue('mailForwardAddress', self['mailForwardAddress']) or []  # FIXME: mapValue returns b'' instead of [b'']
 
