@@ -244,7 +244,7 @@ class License(object):
                 deleted_mods.append(mod)
 
         # remove child modules that were deleted because of an invalid license
-        for _name, mod in univention.admin.modules.modules.items():
+        for mod in univention.admin.modules.modules.values():
             if hasattr(mod, 'childmodules'):
                 new = []
                 for child in mod.childmodules:
@@ -255,7 +255,7 @@ class License(object):
 
         # remove operations for adding or modifying if license is expired
         if self._expired:
-            for _name, mod in univention.admin.modules.modules.items():
+            for mod in univention.admin.modules.modules.values():
                 if hasattr(mod, 'operations'):
                     try:
                         mod.operations.remove('add')
