@@ -70,7 +70,7 @@ def get_superordinate(module, co, lo, dn):
             attr = lo.get(dn)
             super_module = {univention.admin.modules.name(x) for x in univention.admin.modules.identify(dn, attr)} & super_modules
             if super_module:
-                super_module = univention.admin.modules.get(list(super_module)[0])
+                super_module = univention.admin.modules.get(list(super_module)[0])  # noqa: RUF015
                 return get(super_module, co, lo, None, dn)
             dn = lo.parentDn(dn)
 
